==> modesto-1.0.2.tgz: package/README.md <==
# Modesto CSS

Um framework CSS simples (fortemente inspirado pelo visual do [CodyFrame](https://codyhouse.co/ds/docs/framework)), para estilizar minimamente um conteúdo tipo "texto" sem precisar adicionar nenhuma classe (ou o mínimo) aos elementos nativos.

👉 Documentação e demonstração: https://modesto.netlify.app/

> **modesto:** dotado de modéstia; isento de vaidade; simples, despretensioso.

---

## Utilização

Versão com o [CSS aberto](https://unpkg.com/modesto@latest/modesto.css):

```
<link rel="stylesheet" href="https://unpkg.com/modesto@latest/modesto.css">
```

Versão com o [CSS minificado](https://unpkg.com/modesto@latest/modesto.min.css):

```
<link rel="stylesheet" href="https://unpkg.com/modesto@latest/modesto.min.css">
```

---

## Princípios

1.  📖 Semântico
2.  👋 Independente de qualquer conteúdo externo
3.  ♿️ Acessível
4.  🤓 *ClassLess*: evitar ao máximo a necessidade colocar `class` nos elementos
5.  ⚡️ Leve, MUITO leve para se "embedado" direto na página, `1.574 Kb`
6.  🖥 Desktop first, por que no fundo, no fundo, é assim que a maioria dos programadores monta os layouts

## Development Scripts

This "bootstrap" is based on the awesome [HTML SASS Jumpstart](https://github.com/5t3ph/html-sass-jumpstart) from [5t3ph](https://github.com/5t3ph).

**`npm run develop`**

> Serve with hot reload at localhost:1337

**`npm run build`**

> Generate minified, autoprefixed CSS for production

Use this as the "Publish command" if needed by hosting such as Netlify.

**`npm run serve`**

> Serve latest build files at localhost:1337

---

[![Netlify Status](https://api.netlify.com/api/v1/badges/4e99a990-c943-4861-8d48-4985dabd87e3/deploy-status)](https://app.netlify.com/sites/modesto/deploys)

==> modesto-1.0.3.tgz: package/README.md <==
# Modesto CSS ![GitHub package.json version](https://img.shields.io/github/package-json/v/nalmeida/modesto)

Um framework CSS simples (fortemente inspirado pelo visual do [CodyFrame](https://codyhouse.co/ds/docs/framework)), para estilizar minimamente um conteúdo tipo "texto" sem precisar adicionar nenhuma classe (ou o mínimo) aos elementos nativos.

👉 Documentação e demonstração: https://modesto.netlify.app/

> **modesto:** dotado de modéstia; isento de vaidade; simples, despretensioso.

---

## Utilização

Versão com o [CSS aberto](https://unpkg.com/modesto@latest/modesto.css) ![Standard CSS size](https://img.badgesize.io/nalmeida/modesto/master/modesto.css.png):

```
<link rel="stylesheet" href="https://unpkg.com/modesto@latest/modesto.css">
```

Versão com o [CSS minificado](https://unpkg.com/modesto@latest/modesto.min.css) ![GZIPed CSS size](https://img.badgesize.io/nalmeida/modesto/master/modesto.min.css.png?compression=gzip):

```
<link rel="stylesheet" href="https://unpkg.com/modesto@latest/modesto.min.css">
```

---

## Princípios

1.  📖 Semântico
2.  👋 Independente de qualquer conteúdo externo
3.  ♿️ Acessível
4.  🤓 *ClassLess*: evitar ao máximo a necessidade colocar `class` nos elementos
5.  ⚡️ Leve, MUITO leve para se "embedado" direto na página, `1.574 Kb`

## Development Scripts

This "bootstrap" is based on the awesome [HTML SASS Jumpstart](https://github.com/5t3ph/html-sass-jumpstart) from [5t3ph](https://github.com/5t3ph).

**`npm run develop`**

> Serve with hot reload at localhost:1337

**`npm run build`**

> Generate minified, autoprefixed CSS for production

Use this as the "Publish command" if needed by hosting such as Netlify.

**`npm run serve`**

> Serve latest build files at localhost:1337

---

[![Netlify Status](https://api.netlify.com/api/v1/badges/4e99a990-c943-4861-8d48-4985dabd87e3/deploy-status)](https://app.netlify.com/sites/modesto/deploys)
